@@ -13,20 +13,14 @@ use reqwest_middleware::ClientWithMiddleware;
 use tokio::sync::Semaphore;
 use tracing::{info_span, instrument, trace, warn, Instrument};
 use url::Url;
-use uv_auth::UrlAuthPolicies;
 
-use crate::base_client::{BaseClientBuilder, ExtraMiddleware};
-use crate::cached_client::CacheControl;
-use crate::html::SimpleHtml;
-use crate::remote_metadata::wheel_metadata_from_remote_zip;
-use crate::rkyvutil::OwnedArchive;
-use crate::{BaseClient, CachedClient, CachedClientError, Error, ErrorKind};
+use uv_auth::UrlAuthPolicies;
 use uv_cache::{Cache, CacheBucket, CacheEntry, WheelCache};
 use uv_configuration::KeyringProviderType;
 use uv_configuration::{IndexStrategy, TrustedHost};
 use uv_distribution_filename::{DistFilename, SourceDistFilename, WheelFilename};
 use uv_distribution_types::{
-    BuiltDist, File, FileLocation, Index, IndexCapabilities, IndexUrl, IndexUrls, Name,
+    BuiltDist, File, FileLocation, IndexCapabilities, IndexMetadataRef, IndexUrl, IndexUrls, Name,
 };
 use uv_metadata::{read_metadata_async_seek, read_metadata_async_stream};
 use uv_normalize::PackageName;
@@ -35,12 +29,21 @@ use uv_pep508::MarkerEnvironment;
 use uv_platform_tags::Platform;
 use uv_pypi_types::{ResolutionMetadata, SimpleJson};
 use uv_small_str::SmallString;
+use uv_torch::TorchStrategy;
+
+use crate::base_client::{BaseClientBuilder, ExtraMiddleware};
+use crate::cached_client::CacheControl;
+use crate::html::SimpleHtml;
+use crate::remote_metadata::wheel_metadata_from_remote_zip;
+use crate::rkyvutil::OwnedArchive;
+use crate::{BaseClient, CachedClient, CachedClientError, Error, ErrorKind};
 
 /// A builder for an [`RegistryClient`].
 #[derive(Debug, Clone)]
 pub struct RegistryClientBuilder<'a> {
     index_urls: IndexUrls,
     index_strategy: IndexStrategy,
+    torch_backend: Option<TorchStrategy>,
     cache: Cache,
     base_client_builder: BaseClientBuilder<'a>,
 }
@@ -50,6 +53,7 @@ impl RegistryClientBuilder<'_> {
         Self {
             index_urls: IndexUrls::default(),
             index_strategy: IndexStrategy::default(),
+            torch_backend: None,
             cache,
             base_client_builder: BaseClientBuilder::new(),
         }
@@ -69,6 +73,12 @@ impl<'a> RegistryClientBuilder<'a> {
         self
     }
 
+    #[must_use]
+    pub fn torch_backend(mut self, torch_backend: Option<TorchStrategy>) -> Self {
+        self.torch_backend = torch_backend;
+        self
+    }
+
     #[must_use]
     pub fn keyring(mut self, keyring_type: KeyringProviderType) -> Self {
         self.base_client_builder = self.base_client_builder.keyring(keyring_type);
@@ -154,6 +164,7 @@ impl<'a> RegistryClientBuilder<'a> {
         RegistryClient {
             index_urls: self.index_urls,
             index_strategy: self.index_strategy,
+            torch_backend: self.torch_backend,
             cache: self.cache,
             connectivity,
             client,
@@ -175,6 +186,7 @@ impl<'a> RegistryClientBuilder<'a> {
         RegistryClient {
             index_urls: self.index_urls,
             index_strategy: self.index_strategy,
+            torch_backend: self.torch_backend,
             cache: self.cache,
             connectivity,
             client,
@@ -190,6 +202,7 @@ impl<'a> TryFrom<BaseClientBuilder<'a>> for RegistryClientBuilder<'a> {
         Ok(Self {
             index_urls: IndexUrls::default(),
             index_strategy: IndexStrategy::default(),
+            torch_backend: None,
             cache: Cache::temp()?,
             base_client_builder: value,
         })
@@ -203,6 +216,8 @@ pub struct RegistryClient {
     index_urls: IndexUrls,
     /// The strategy to use when fetching across multiple indexes.
     index_strategy: IndexStrategy,
+    /// The strategy to use when selecting a PyTorch backend, if any.
+    torch_backend: Option<TorchStrategy>,
     /// The underlying HTTP client.
     client: CachedClient,
     /// Used for the remote wheel METADATA cache.
@@ -239,6 +254,32 @@ impl RegistryClient {
         self.timeout
     }
 
+    /// Return the appropriate index URLs for the given [`PackageName`].
+    fn index_urls_for(&self, package_name: &PackageName) -> impl Iterator<Item = IndexMetadataRef> {
+        self.torch_backend
+            .as_ref()
+            .and_then(|torch_backend| {
+                torch_backend
+                    .applies_to(package_name)
+                    .then(|| torch_backend.index_urls())
+                    .map(|indexes| indexes.map(IndexMetadataRef::from))
+            })
+            .map(Either::Left)
+            .unwrap_or_else(|| Either::Right(self.index_urls.indexes().map(IndexMetadataRef::from)))
+    }
+
+    /// Return the appropriate [`IndexStrategy`] for the given [`PackageName`].
+    fn index_strategy_for(&self, package_name: &PackageName) -> IndexStrategy {
+        self.torch_backend
+            .as_ref()
+            .and_then(|torch_backend| {
+                torch_backend
+                    .applies_to(package_name)
+                    .then_some(IndexStrategy::UnsafeFirstMatch)
+            })
+            .unwrap_or(self.index_strategy)
+    }
+
     /// Fetch a package from the `PyPI` simple API.
     ///
     /// "simple" here refers to [PEP 503 – Simple Repository API](https://peps.python.org/pep-0503/)
@@ -248,30 +289,31 @@ impl RegistryClient {
     pub async fn simple<'index>(
         &'index self,
         package_name: &PackageName,
-        index: Option<&'index IndexUrl>,
+        index: Option<IndexMetadataRef<'index>>,
         capabilities: &IndexCapabilities,
         download_concurrency: &Semaphore,
-    ) -> Result<Vec<(&'index IndexUrl, OwnedArchive<SimpleMetadata>)>, Error> {
-        let indexes = if let Some(index) = index {
-            Either::Left(std::iter::once(index))
-        } else {
-            Either::Right(self.index_urls.indexes().map(Index::url))
-        };
-
-        let mut it = indexes.peekable();
-        if it.peek().is_none() {
+    ) -> Result<Vec<(IndexMetadataRef<'index>, OwnedArchive<SimpleMetadata>)>, Error> {
+        // If `--no-index` is specified, avoid fetching regardless of whether the index is implicit,
+        // explicit, etc.
+        if self.index_urls.no_index() {
             return Err(ErrorKind::NoIndex(package_name.to_string()).into());
         }
 
+        let indexes = if let Some(index) = index {
+            Either::Left(std::iter::once(index))
+        } else {
+            Either::Right(self.index_urls_for(package_name))
+        };
+
         let mut results = Vec::new();
 
-        match self.index_strategy {
+        match self.index_strategy_for(package_name) {
             // If we're searching for the first index that contains the package, fetch serially.
             IndexStrategy::FirstIndex => {
-                for index in it {
+                for index in indexes {
                     let _permit = download_concurrency.acquire().await;
                     if let Some(metadata) = self
-                        .simple_single_index(package_name, index, capabilities)
+                        .simple_single_index(package_name, index.url(), capabilities)
                         .await?
                     {
                         results.push((index, metadata));
@@ -282,11 +324,11 @@ impl RegistryClient {
 
             // Otherwise, fetch concurrently.
             IndexStrategy::UnsafeBestMatch | IndexStrategy::UnsafeFirstMatch => {
-                results = futures::stream::iter(it)
+                results = futures::stream::iter(indexes)
                     .map(|index| async move {
                         let _permit = download_concurrency.acquire().await;
                         let metadata = self
-                            .simple_single_index(package_name, index, capabilities)
+                            .simple_single_index(package_name, index.url(), capabilities)
                             .await?;
                         Ok((index, metadata))
                     })
@@ -328,9 +370,9 @@ impl RegistryClient {
         capabilities: &IndexCapabilities,
     ) -> Result<Option<OwnedArchive<SimpleMetadata>>, Error> {
         // Format the URL for PyPI.
-        let mut url: Url = index.clone().into();
+        let mut url = index.url().clone();
         url.path_segments_mut()
-            .map_err(|()| ErrorKind::CannotBeABase(index.clone().into()))?
+            .map_err(|()| ErrorKind::CannotBeABase(index.url().clone()))?
             .pop_if_empty()
             .push(package_name.as_ref())
             // The URL *must* end in a trailing slash for proper relative path behavior
@@ -581,7 +623,7 @@ impl RegistryClient {
                 .await?
             }
             BuiltDist::Path(wheel) => {
-                let file = fs_err::tokio::File::open(&wheel.install_path)
+                let file = fs_err::tokio::File::open(wheel.install_path.as_ref())
                     .await
                     .map_err(ErrorKind::Io)?;
                 let reader = tokio::io::BufReader::new(file);
@@ -1113,13 +1155,13 @@ mod tests {
             .map(|file| uv_pypi_types::base_url_join_relative(base.as_url().as_str(), &file.url))
             .collect::<Result<Vec<_>, JoinRelativeError>>()?;
         let urls = urls.iter().map(Url::as_str).collect::<Vec<_>>();
-        insta::assert_debug_snapshot!(urls, @r###"
-    [
-        "https://account.d.codeartifact.us-west-2.amazonaws.com/pypi/shared-packages-pypi/simple/0.1/Flask-0.1.tar.gz#sha256=9da884457e910bf0847d396cb4b778ad9f3c3d17db1c5997cb861937bd284237",
-        "https://account.d.codeartifact.us-west-2.amazonaws.com/pypi/shared-packages-pypi/simple/0.10.1/Flask-0.10.1.tar.gz#sha256=4c83829ff83d408b5e1d4995472265411d2c414112298f2eb4b359d9e4563373",
-        "https://account.d.codeartifact.us-west-2.amazonaws.com/pypi/shared-packages-pypi/simple/3.0.1/flask-3.0.1.tar.gz#sha256=6489f51bb3666def6f314e15f19d50a1869a19ae0e8c9a3641ffe66c77d42403",
-    ]
-    "###);
+        insta::assert_debug_snapshot!(urls, @r#"
+        [
+            "https://account.d.codeartifact.us-west-2.amazonaws.com/pypi/shared-packages-pypi/simple/0.1/Flask-0.1.tar.gz",
+            "https://account.d.codeartifact.us-west-2.amazonaws.com/pypi/shared-packages-pypi/simple/0.10.1/Flask-0.10.1.tar.gz",
+            "https://account.d.codeartifact.us-west-2.amazonaws.com/pypi/shared-packages-pypi/simple/3.0.1/flask-3.0.1.tar.gz",
+        ]
+        "#);
 
         Ok(())
     }
