@@ -3,7 +3,7 @@ pub use build_options::*;
 pub use concurrency::*;
 pub use config_settings::*;
 pub use constraints::*;
-pub use dev::*;
+pub use dependency_groups::*;
 pub use dry_run::*;
 pub use editable::*;
 pub use export_format::*;
@@ -28,7 +28,7 @@ mod build_options;
 mod concurrency;
 mod config_settings;
 mod constraints;
-mod dev;
+mod dependency_groups;
 mod dry_run;
 mod editable;
 mod export_format;
