@@ -4,6 +4,7 @@ use clap::Parser;
 use tracing::info;
 
 use uv_cache::{Cache, CacheArgs};
+use uv_configuration::Concurrency;
 use uv_python::{EnvironmentPreference, PythonEnvironment, PythonRequest};
 
 #[derive(Parser)]
@@ -33,6 +34,7 @@ pub(crate) async fn compile(args: CompileArgs) -> anyhow::Result<()> {
     let files = uv_installer::compile_tree(
         &fs_err::canonicalize(args.root)?,
         &interpreter,
+        &Concurrency::default(),
         cache.root(),
     )
     .await?;
