@@ -34,7 +34,7 @@
 //! Since we read this information from [`direct_url.json`](https://packaging.python.org/en/latest/specifications/direct-url-data-structure/), it doesn't match the information [`Dist`] exactly.
 use std::borrow::Cow;
 use std::path;
-use std::path::{Path, PathBuf};
+use std::path::Path;
 use std::str::FromStr;
 
 use url::Url;
@@ -71,6 +71,7 @@ pub use crate::origin::*;
 pub use crate::pip_index::*;
 pub use crate::prioritized_distribution::*;
 pub use crate::requested::*;
+pub use crate::requirement::*;
 pub use crate::resolution::*;
 pub use crate::resolved::*;
 pub use crate::specified_requirement::*;
@@ -96,6 +97,7 @@ mod origin;
 mod pip_index;
 mod prioritized_distribution;
 mod requested;
+mod requirement;
 mod resolution;
 mod resolved;
 mod specified_requirement;
@@ -264,7 +266,7 @@ pub struct DirectUrlBuiltDist {
 pub struct PathBuiltDist {
     pub filename: WheelFilename,
     /// The absolute path to the wheel which we use for installing.
-    pub install_path: PathBuf,
+    pub install_path: Box<Path>,
     /// The URL as it was provided by the user.
     pub url: VerbatimUrl,
 }
@@ -297,7 +299,7 @@ pub struct DirectUrlSourceDist {
     /// The URL without the subdirectory fragment.
     pub location: Box<Url>,
     /// The subdirectory within the archive in which the source distribution is located.
-    pub subdirectory: Option<PathBuf>,
+    pub subdirectory: Option<Box<Path>>,
     /// The file extension, e.g. `tar.gz`, `zip`, etc.
     pub ext: SourceDistExtension,
     /// The URL as it was provided by the user, including the subdirectory fragment.
@@ -311,7 +313,7 @@ pub struct GitSourceDist {
     /// The URL without the revision and subdirectory fragment.
     pub git: Box<GitUrl>,
     /// The subdirectory within the Git repository in which the source distribution is located.
-    pub subdirectory: Option<PathBuf>,
+    pub subdirectory: Option<Box<Path>>,
     /// The URL as it was provided by the user, including the revision and subdirectory fragment.
     pub url: VerbatimUrl,
 }
@@ -322,7 +324,7 @@ pub struct PathSourceDist {
     pub name: PackageName,
     pub version: Option<Version>,
     /// The absolute path to the distribution which we use for installing.
-    pub install_path: PathBuf,
+    pub install_path: Box<Path>,
     /// The file extension, e.g. `tar.gz`, `zip`, etc.
     pub ext: SourceDistExtension,
     /// The URL as it was provided by the user.
@@ -334,7 +336,7 @@ pub struct PathSourceDist {
 pub struct DirectorySourceDist {
     pub name: PackageName,
     /// The absolute path to the distribution which we use for installing.
-    pub install_path: PathBuf,
+    pub install_path: Box<Path>,
     /// Whether the package should be installed in editable mode.
     pub editable: bool,
     /// Whether the package should be built and installed.
@@ -350,7 +352,7 @@ impl Dist {
         name: PackageName,
         url: VerbatimUrl,
         location: Url,
-        subdirectory: Option<PathBuf>,
+        subdirectory: Option<Box<Path>>,
         ext: DistExtension,
     ) -> Result<Dist, Error> {
         match ext {
@@ -415,7 +417,7 @@ impl Dist {
                 }
                 Ok(Self::Built(BuiltDist::Path(PathBuiltDist {
                     filename,
-                    install_path,
+                    install_path: install_path.into_boxed_path(),
                     url,
                 })))
             }
@@ -432,7 +434,7 @@ impl Dist {
                 Ok(Self::Source(SourceDist::Path(PathSourceDist {
                     name,
                     version,
-                    install_path,
+                    install_path: install_path.into_boxed_path(),
                     ext,
                     url,
                 })))
@@ -462,7 +464,7 @@ impl Dist {
         // Determine whether the path represents an archive or a directory.
         Ok(Self::Source(SourceDist::Directory(DirectorySourceDist {
             name,
-            install_path,
+            install_path: install_path.into_boxed_path(),
             editable,
             r#virtual,
             url,
@@ -474,7 +476,7 @@ impl Dist {
         name: PackageName,
         url: VerbatimUrl,
         git: GitUrl,
-        subdirectory: Option<PathBuf>,
+        subdirectory: Option<Box<Path>>,
     ) -> Result<Dist, Error> {
         Ok(Self::Source(SourceDist::Git(GitSourceDist {
             name,
@@ -637,6 +639,7 @@ impl SourceDist {
         }
     }
 
+    /// Returns the [`Version`] of the distribution, if it is known.
     pub fn version(&self) -> Option<&Version> {
         match self {
             Self::Registry(source_dist) => Some(&source_dist.version),
@@ -644,7 +647,7 @@ impl SourceDist {
         }
     }
 
-    /// Return true if the distribution is editable.
+    /// Returns `true` if the distribution is editable.
     pub fn is_editable(&self) -> bool {
         match self {
             Self::Directory(DirectorySourceDist { editable, .. }) => *editable,
@@ -652,7 +655,15 @@ impl SourceDist {
         }
     }
 
-    /// Return true if the distribution refers to a local file or directory.
+    /// Returns `true` if the distribution is virtual.
+    pub fn is_virtual(&self) -> bool {
+        match self {
+            Self::Directory(DirectorySourceDist { r#virtual, .. }) => *r#virtual,
+            _ => false,
+        }
+    }
+
+    /// Returns `true` if the distribution refers to a local file or directory.
     pub fn is_local(&self) -> bool {
         matches!(self, Self::Directory(_) | Self::Path(_))
     }
@@ -666,7 +677,7 @@ impl SourceDist {
         }
     }
 
-    /// Return the source tree of the distribution, if available.
+    /// Returns the source tree of the distribution, if available.
     pub fn source_tree(&self) -> Option<&Path> {
         match self {
             Self::Directory(dist) => Some(&dist.install_path),
