@@ -7,14 +7,14 @@ use thiserror::Error;
 use url::Url;
 
 use uv_distribution_filename::DistExtension;
-use uv_distribution_types::{Index, IndexLocations, IndexName, Origin};
+use uv_distribution_types::{
+    Index, IndexLocations, IndexMetadata, IndexName, Origin, Requirement, RequirementSource,
+};
 use uv_git_types::{GitReference, GitUrl, GitUrlParseError};
 use uv_normalize::{ExtraName, GroupName, PackageName};
 use uv_pep440::VersionSpecifiers;
 use uv_pep508::{looks_like_git_repository, MarkerTree, VerbatimUrl, VersionOrUrl};
-use uv_pypi_types::{
-    ConflictItem, ParsedUrlError, Requirement, RequirementSource, VerbatimParsedUrl,
-};
+use uv_pypi_types::{ConflictItem, ParsedUrlError, VerbatimParsedUrl};
 use uv_workspace::pyproject::{PyProjectToml, Source, Sources};
 use uv_workspace::Workspace;
 
@@ -171,7 +171,7 @@ impl LoweredRequirement {
                         } => {
                             let source = git_source(
                                 &git,
-                                subdirectory.map(PathBuf::from),
+                                subdirectory.map(Box::<Path>::from),
                                 rev,
                                 tag,
                                 branch,
@@ -185,7 +185,7 @@ impl LoweredRequirement {
                             ..
                         } => {
                             let source =
-                                url_source(&requirement, url, subdirectory.map(PathBuf::from))?;
+                                url_source(&requirement, url, subdirectory.map(Box::<Path>::from))?;
                             (source, marker)
                         }
                         Source::Path {
@@ -196,7 +196,7 @@ impl LoweredRequirement {
                             ..
                         } => {
                             let source = path_source(
-                                PathBuf::from(path),
+                                path,
                                 git_member,
                                 origin,
                                 project_dir,
@@ -222,7 +222,9 @@ impl LoweredRequirement {
                                 .find(|Index { name, .. }| {
                                     name.as_ref().is_some_and(|name| *name == index)
                                 })
-                                .map(|Index { url: index, .. }| index.clone())
+                                .map(|index| IndexMetadata {
+                                    url: index.url.clone(),
+                                })
                             else {
                                 return Err(LoweringError::MissingIndex(
                                     requirement.name.clone(),
@@ -238,7 +240,7 @@ impl LoweredRequirement {
                                     })
                                 }
                             });
-                            let source = registry_source(&requirement, index.into_url(), conflict);
+                            let source = registry_source(&requirement, index, conflict);
                             (source, marker)
                         }
                         Source::Workspace {
@@ -296,20 +298,20 @@ impl LoweredRequirement {
                                     subdirectory: if subdirectory == PathBuf::new() {
                                         None
                                     } else {
-                                        Some(subdirectory)
+                                        Some(subdirectory.into_boxed_path())
                                     },
                                     url,
                                 }
                             } else if member.pyproject_toml().is_package() {
                                 RequirementSource::Directory {
-                                    install_path,
+                                    install_path: install_path.into_boxed_path(),
                                     url,
                                     editable: true,
                                     r#virtual: false,
                                 }
                             } else {
                                 RequirementSource::Directory {
-                                    install_path,
+                                    install_path: install_path.into_boxed_path(),
                                     url,
                                     editable: false,
                                     r#virtual: true,
@@ -324,7 +326,7 @@ impl LoweredRequirement {
                     Ok(Self(Requirement {
                         name: requirement.name.clone(),
                         extras: requirement.extras.clone(),
-                        groups: vec![],
+                        groups: Box::new([]),
                         marker,
                         source,
                         origin: requirement.origin.clone(),
@@ -402,7 +404,7 @@ impl LoweredRequirement {
                         } => {
                             let source = git_source(
                                 &git,
-                                subdirectory.map(PathBuf::from),
+                                subdirectory.map(Box::<Path>::from),
                                 rev,
                                 tag,
                                 branch,
@@ -416,7 +418,7 @@ impl LoweredRequirement {
                             ..
                         } => {
                             let source =
-                                url_source(&requirement, url, subdirectory.map(PathBuf::from))?;
+                                url_source(&requirement, url, subdirectory.map(Box::<Path>::from))?;
                             (source, marker)
                         }
                         Source::Path {
@@ -427,7 +429,7 @@ impl LoweredRequirement {
                             ..
                         } => {
                             let source = path_source(
-                                PathBuf::from(path),
+                                path,
                                 None,
                                 RequirementOrigin::Project,
                                 dir,
@@ -445,7 +447,9 @@ impl LoweredRequirement {
                                 .find(|Index { name, .. }| {
                                     name.as_ref().is_some_and(|name| *name == index)
                                 })
-                                .map(|Index { url: index, .. }| index.clone())
+                                .map(|index| IndexMetadata {
+                                    url: index.url.clone(),
+                                })
                             else {
                                 return Err(LoweringError::MissingIndex(
                                     requirement.name.clone(),
@@ -453,7 +457,7 @@ impl LoweredRequirement {
                                 ));
                             };
                             let conflict = None;
-                            let source = registry_source(&requirement, index.into_url(), conflict);
+                            let source = registry_source(&requirement, index, conflict);
                             (source, marker)
                         }
                         Source::Workspace { .. } => {
@@ -466,7 +470,7 @@ impl LoweredRequirement {
                     Ok(Self(Requirement {
                         name: requirement.name.clone(),
                         extras: requirement.extras.clone(),
-                        groups: vec![],
+                        groups: Box::new([]),
                         marker,
                         source,
                         origin: requirement.origin.clone(),
@@ -550,7 +554,7 @@ impl std::fmt::Display for SourceKind {
 /// Convert a Git source into a [`RequirementSource`].
 fn git_source(
     git: &Url,
-    subdirectory: Option<PathBuf>,
+    subdirectory: Option<Box<Path>>,
     rev: Option<String>,
     tag: Option<String>,
     branch: Option<String>,
@@ -571,7 +575,7 @@ fn git_source(
     if let Some(subdirectory) = subdirectory.as_ref() {
         let subdirectory = subdirectory
             .to_str()
-            .ok_or_else(|| LoweringError::NonUtf8Path(subdirectory.clone()))?;
+            .ok_or_else(|| LoweringError::NonUtf8Path(subdirectory.to_path_buf()))?;
         url.set_fragment(Some(&format!("subdirectory={subdirectory}")));
     }
     let url = VerbatimUrl::from_url(url);
@@ -589,7 +593,7 @@ fn git_source(
 fn url_source(
     requirement: &uv_pep508::Requirement<VerbatimParsedUrl>,
     url: Url,
-    subdirectory: Option<PathBuf>,
+    subdirectory: Option<Box<Path>>,
 ) -> Result<RequirementSource, LoweringError> {
     let mut verbatim_url = url.clone();
     if verbatim_url.fragment().is_some() {
@@ -598,7 +602,7 @@ fn url_source(
     if let Some(subdirectory) = subdirectory.as_ref() {
         let subdirectory = subdirectory
             .to_str()
-            .ok_or_else(|| LoweringError::NonUtf8Path(subdirectory.clone()))?;
+            .ok_or_else(|| LoweringError::NonUtf8Path(subdirectory.to_path_buf()))?;
         verbatim_url.set_fragment(Some(&format!("subdirectory={subdirectory}")));
     }
 
@@ -627,7 +631,7 @@ fn url_source(
 /// Convert a registry source into a [`RequirementSource`].
 fn registry_source(
     requirement: &uv_pep508::Requirement<VerbatimParsedUrl>,
-    index: Url,
+    index: IndexMetadata,
     conflict: Option<ConflictItem>,
 ) -> RequirementSource {
     match &requirement.version_or_url {
@@ -687,7 +691,7 @@ fn path_source(
                 subdirectory: if subdirectory == PathBuf::new() {
                     None
                 } else {
-                    Some(subdirectory)
+                    Some(subdirectory.into_boxed_path())
                 },
                 url,
             });
@@ -695,7 +699,7 @@ fn path_source(
 
         if editable == Some(true) {
             Ok(RequirementSource::Directory {
-                install_path,
+                install_path: install_path.into_boxed_path(),
                 url,
                 editable: true,
                 r#virtual: false,
@@ -712,7 +716,7 @@ fn path_source(
             });
 
             Ok(RequirementSource::Directory {
-                install_path,
+                install_path: install_path.into_boxed_path(),
                 url,
                 editable: false,
                 // If a project is not a package, treat it as a virtual dependency.
@@ -733,7 +737,7 @@ fn path_source(
         Ok(RequirementSource::Path {
             ext: DistExtension::from_path(&install_path)
                 .map_err(|err| ParsedUrlError::MissingExtensionPath(path.to_path_buf(), err))?,
-            install_path,
+            install_path: install_path.into_boxed_path(),
             url,
         })
     }
