@@ -344,7 +344,7 @@ pub fn relative_to(
 pub struct PortablePath<'a>(&'a Path);
 
 #[derive(Debug, Clone, PartialEq, Eq)]
-pub struct PortablePathBuf(PathBuf);
+pub struct PortablePathBuf(Box<Path>);
 
 #[cfg(feature = "schemars")]
 impl schemars::JsonSchema for PortablePathBuf {
@@ -397,21 +397,21 @@ impl std::fmt::Display for PortablePathBuf {
 impl From<&str> for PortablePathBuf {
     fn from(path: &str) -> Self {
         if path == "." {
-            Self(PathBuf::new())
+            Self(PathBuf::new().into_boxed_path())
         } else {
-            Self(PathBuf::from(path))
+            Self(PathBuf::from(path).into_boxed_path())
         }
     }
 }
 
-impl From<PortablePathBuf> for PathBuf {
+impl From<PortablePathBuf> for Box<Path> {
     fn from(portable: PortablePathBuf) -> Self {
         portable.0
     }
 }
 
-impl From<PathBuf> for PortablePathBuf {
-    fn from(path: PathBuf) -> Self {
+impl From<Box<Path>> for PortablePathBuf {
+    fn from(path: Box<Path>) -> Self {
         Self(path)
     }
 }
@@ -444,13 +444,19 @@ impl<'de> serde::de::Deserialize<'de> for PortablePathBuf {
     {
         let s = String::deserialize(deserializer)?;
         if s == "." {
-            Ok(Self(PathBuf::new()))
+            Ok(Self(PathBuf::new().into_boxed_path()))
         } else {
-            Ok(Self(PathBuf::from(s)))
+            Ok(Self(PathBuf::from(s).into_boxed_path()))
         }
     }
 }
 
+impl AsRef<Path> for PortablePathBuf {
+    fn as_ref(&self) -> &Path {
+        &self.0
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
