@@ -8,9 +8,11 @@ pub async fn uninstall(
         let dist = dist.clone();
         move || match dist {
             InstalledDist::Registry(_) | InstalledDist::Url(_) => {
-                Ok(uv_install_wheel::uninstall_wheel(dist.path())?)
+                Ok(uv_install_wheel::uninstall_wheel(dist.install_path())?)
+            }
+            InstalledDist::EggInfoDirectory(_) => {
+                Ok(uv_install_wheel::uninstall_egg(dist.install_path())?)
             }
-            InstalledDist::EggInfoDirectory(_) => Ok(uv_install_wheel::uninstall_egg(dist.path())?),
             InstalledDist::LegacyEditable(dist) => {
                 Ok(uv_install_wheel::uninstall_legacy_editable(&dist.egg_link)?)
             }
