@@ -5,13 +5,13 @@ use std::str::FromStr;
 use itertools::Either;
 use rustc_hash::FxHashSet;
 
-use uv_configuration::{DevGroupsManifest, ExtrasSpecification};
+use uv_configuration::{DependencyGroupsWithDefaults, ExtrasSpecification};
 use uv_distribution_types::Index;
 use uv_normalize::PackageName;
-use uv_pypi_types::{LenientRequirement, VerbatimParsedUrl};
+use uv_pypi_types::{DependencyGroupSpecifier, LenientRequirement, VerbatimParsedUrl};
 use uv_resolver::{Installable, Lock, Package};
 use uv_scripts::Pep723Script;
-use uv_workspace::pyproject::{DependencyGroupSpecifier, Source, Sources, ToolUvSources};
+use uv_workspace::pyproject::{Source, Sources, ToolUvSources};
 use uv_workspace::Workspace;
 
 use crate::commands::project::ProjectError;
@@ -299,7 +299,10 @@ impl<'lock> InstallTarget<'lock> {
 
     /// Validate the dependency groups requested by the [`DependencyGroupSpecifier`].
     #[allow(clippy::result_large_err)]
-    pub(crate) fn validate_groups(self, groups: &DevGroupsManifest) -> Result<(), ProjectError> {
+    pub(crate) fn validate_groups(
+        self,
+        groups: &DependencyGroupsWithDefaults,
+    ) -> Result<(), ProjectError> {
         // If no groups were specified, short-circuit.
         if groups.explicit_names().next().is_none() {
             return Ok(());
