@@ -431,3 +431,119 @@ fn rename_module_editable_build() -> Result<()> {
 
     Ok(())
 }
+
+/// Check that the build succeeds even if the module name mismatches by case.
+#[test]
+fn build_module_name_normalization() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let wheel_dir = context.temp_dir.path().join("dist");
+    fs_err::create_dir(&wheel_dir)?;
+
+    context
+        .temp_dir
+        .child("pyproject.toml")
+        .write_str(indoc! {r#"
+        [project]
+        name = "django-plugin"
+        version = "1.0.0"
+
+        [build-system]
+        requires = ["uv_build>=0.5,<0.7"]
+        build-backend = "uv_build"
+    "#})?;
+    fs_err::create_dir_all(context.temp_dir.join("src"))?;
+
+    // Error case 1: No matching module.
+    uv_snapshot!(context
+        .build_backend()
+        .arg("build-wheel")
+        .arg(&wheel_dir), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Expected a Python module directory at: `src/django_plugin`
+    "###);
+
+    fs_err::create_dir_all(context.temp_dir.join("src/Django_plugin"))?;
+    // Error case 2: A matching module, but no `__init__.py`.
+    uv_snapshot!(context
+        .build_backend()
+        .arg("build-wheel")
+        .arg(&wheel_dir), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Expected an `__init__.py` at: `src/Django_plugin/__init__.py`
+    "###);
+
+    // Use `Django_plugin` instead of `django_plugin`
+    context
+        .temp_dir
+        .child("src/Django_plugin/__init__.py")
+        .write_str(r#"print("Hi from bar")"#)?;
+
+    uv_snapshot!(context
+        .build_backend()
+        .arg("build-wheel")
+        .arg(&wheel_dir), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    django_plugin-1.0.0-py3-none-any.whl
+
+    ----- stderr -----
+    ");
+
+    context
+        .pip_install()
+        .arg("--no-index")
+        .arg("--find-links")
+        .arg(&wheel_dir)
+        .arg("django-plugin")
+        .assert()
+        .success();
+
+    uv_snapshot!(Command::new(context.interpreter())
+        .arg("-c")
+        .arg("import Django_plugin")
+        // Python on windows
+        .env(EnvVars::PYTHONUTF8, "1"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    Hi from bar
+
+    ----- stderr -----
+    ");
+
+    // Error case 3: Multiple modules a matching name.
+    // Requires a case-sensitive filesystem.
+    #[cfg(target_os = "linux")]
+    {
+        context
+            .temp_dir
+            .child("src/django_plugin/__init__.py")
+            .write_str(r#"print("Hi from bar")"#)?;
+
+        uv_snapshot!(context
+            .build_backend()
+            .arg("build-wheel")
+            .arg(&wheel_dir), @r"
+        success: false
+        exit_code: 2
+        ----- stdout -----
+
+        ----- stderr -----
+        error: Expected an `__init__.py` at `django_plugin`, found multiple:
+        * `src/Django_plugin`
+        * `src/django_plugin`
+        ");
+    }
+
+    Ok(())
+}
