@@ -224,6 +224,27 @@ impl TestContext {
         self
     }
 
+    /// Add extra filtering for ` -> <PATH>` symlink display for Python versions in the test
+    /// context, e.g., for use in `uv python list`.
+    #[must_use]
+    pub fn with_filtered_python_symlinks(mut self) -> Self {
+        for (version, executable) in &self.python_versions {
+            if fs_err::symlink_metadata(executable).unwrap().is_symlink() {
+                self.filters.extend(
+                    Self::path_patterns(executable.read_link().unwrap())
+                        .into_iter()
+                        .map(|pattern| (format! {" -> {pattern}"}, String::new())),
+                );
+            }
+            // Drop links that are byproducts of the test context too
+            self.filters.push((
+                regex::escape(&format!(" -> [PYTHON-{version}]")),
+                String::new(),
+            ));
+        }
+        self
+    }
+
     /// Add extra standard filtering for a given path.
     #[must_use]
     pub fn with_filtered_path(mut self, path: &Path, name: &str) -> Self {
@@ -256,11 +277,32 @@ impl TestContext {
     /// Adds a filter that ignores platform information in a Python installation key.
     pub fn with_filtered_python_keys(mut self) -> Self {
         // Filter platform keys
-        self.filters.push((
-            r"((?:cpython|pypy)-\d+\.\d+(?:\.(?:\[X\]|\d+))?[a-z]?(?:\+[a-z]+)?)-[a-z0-9]+-[a-z0-9_]+-[a-z]+"
-                .to_string(),
-            "$1-[PLATFORM]".to_string(),
-        ));
+        let platform_re = r"(?x)
+  (                         # We capture the group before the platform
+    (?:cpython|pypy)        # Python implementation
+    -
+    \d+\.\d+                # Major and minor version
+    (?:                     # The patch version is handled separately
+      \.
+      (?:
+        \[X\]               # A previously filtered patch version [X]
+        |                   # OR
+        \d+                 # An actual patch version
+      )
+    )?                      # (we allow the patch version to be missing entirely, e.g., in a request)
+    (?:(?:a|b|rc)[0-9]+)?   # Pre-release version component, e.g., `a6` or `rc2`
+    (?:[td])?               # A short variant, such as `t` (for freethreaded) or `d` (for debug)
+    (?:\+[a-z]+)?           # A long variant, such as `+free-threaded`
+  )
+  -
+  [a-z0-9]+                 # Operating system (e.g., 'macos')
+  -
+  [a-z0-9_]+                # Architecture (e.g., 'aarch64')
+  -
+  [a-z]+                    # Libc (e.g., 'none')
+";
+        self.filters
+            .push((platform_re.to_string(), "$1-[PLATFORM]".to_string()));
         self
     }
 
@@ -803,6 +845,18 @@ impl TestContext {
         command
     }
 
+    /// Create a `uv python list` command with options shared across scenarios.
+    pub fn python_list(&self) -> Command {
+        let mut command = self.new_command();
+        command
+            .arg("python")
+            .arg("list")
+            .env(EnvVars::UV_PYTHON_INSTALL_DIR, "")
+            .current_dir(&self.temp_dir);
+        self.add_shared_options(&mut command, false);
+        command
+    }
+
     /// Create a `uv python install` command with options shared across scenarios.
     pub fn python_install(&self) -> Command {
         let mut command = self.new_command();
