@@ -7,7 +7,7 @@ fn help() {
     let context = TestContext::new_with_versions(&[]);
 
     // The `uv help` command should show the long help message
-    uv_snapshot!(context.filters(), context.help(), @r###"
+    uv_snapshot!(context.filters(), context.help(), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -42,11 +42,10 @@ fn help() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations [env: UV_PYTHON_PREFERENCE=]
-              [possible values: only-managed, managed, system, only-system]
-          --no-python-downloads
-              Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
+          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+          --no-python-downloads  Disable automatic downloads of Python. [env:
+                                 "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet
@@ -81,14 +80,14 @@ fn help() {
 
 
     ----- stderr -----
-    "###);
+    "#);
 }
 
 #[test]
 fn help_flag() {
     let context = TestContext::new_with_versions(&[]);
 
-    uv_snapshot!(context.filters(), context.command().arg("--help"), @r###"
+    uv_snapshot!(context.filters(), context.command().arg("--help"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -122,11 +121,10 @@ fn help_flag() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations [env: UV_PYTHON_PREFERENCE=]
-              [possible values: only-managed, managed, system, only-system]
-          --no-python-downloads
-              Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
+          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+          --no-python-downloads  Disable automatic downloads of Python. [env:
+                                 "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet
@@ -160,14 +158,14 @@ fn help_flag() {
     Use `uv help` for more details.
 
     ----- stderr -----
-    "###);
+    "#);
 }
 
 #[test]
 fn help_short_flag() {
     let context = TestContext::new_with_versions(&[]);
 
-    uv_snapshot!(context.filters(), context.command().arg("-h"), @r###"
+    uv_snapshot!(context.filters(), context.command().arg("-h"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -201,11 +199,10 @@ fn help_short_flag() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations [env: UV_PYTHON_PREFERENCE=]
-              [possible values: only-managed, managed, system, only-system]
-          --no-python-downloads
-              Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
+          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+          --no-python-downloads  Disable automatic downloads of Python. [env:
+                                 "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet
@@ -239,14 +236,14 @@ fn help_short_flag() {
     Use `uv help` for more details.
 
     ----- stderr -----
-    "###);
+    "#);
 }
 
 #[test]
 fn help_subcommand() {
     let context = TestContext::new_with_versions(&[]);
 
-    uv_snapshot!(context.filters(), context.help().arg("python"), @r###"
+    uv_snapshot!(context.filters(), context.help().arg("python"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -318,22 +315,21 @@ fn help_subcommand() {
               [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations.
+          --managed-python
+              Require use of uv-managed Python versions.
               
               By default, uv prefers using Python versions it manages. However, it will use system
-              Python installations if a uv-managed Python is not installed. This option allows
-              prioritizing or ignoring system Python installations.
+              Python versions if a uv-managed Python is not installed. This option disables use of
+              system Python versions.
               
-              [env: UV_PYTHON_PREFERENCE=]
+              [env: UV_MANAGED_PYTHON=]
 
-              Possible values:
-              - only-managed: Only use managed Python installations; never use system Python
-                installations
-              - managed:      Prefer managed Python installations over system Python installations
-              - system:       Prefer system Python installations over managed Python installations
-              - only-system:  Only use system Python installations; never use managed Python
-                installations
+          --no-managed-python
+              Disable use of uv-managed Python versions.
+              
+              Instead, uv will search for a suitable Python version on the system.
+              
+              [env: UV_NO_MANAGED_PYTHON=]
 
           --no-python-downloads
               Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
@@ -447,14 +443,14 @@ fn help_subcommand() {
 
 
     ----- stderr -----
-    "###);
+    "#);
 }
 
 #[test]
 fn help_subsubcommand() {
     let context = TestContext::new_with_versions(&[]);
 
-    uv_snapshot!(context.filters(), context.help().env_remove(EnvVars::UV_PYTHON_INSTALL_DIR).arg("python").arg("install"), @r###"
+    uv_snapshot!(context.filters(), context.help().env_remove(EnvVars::UV_PYTHON_INSTALL_DIR).arg("python").arg("install"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -567,22 +563,21 @@ fn help_subsubcommand() {
               [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations.
+          --managed-python
+              Require use of uv-managed Python versions.
               
               By default, uv prefers using Python versions it manages. However, it will use system
-              Python installations if a uv-managed Python is not installed. This option allows
-              prioritizing or ignoring system Python installations.
+              Python versions if a uv-managed Python is not installed. This option disables use of
+              system Python versions.
               
-              [env: UV_PYTHON_PREFERENCE=]
+              [env: UV_MANAGED_PYTHON=]
 
-              Possible values:
-              - only-managed: Only use managed Python installations; never use system Python
-                installations
-              - managed:      Prefer managed Python installations over system Python installations
-              - system:       Prefer system Python installations over managed Python installations
-              - only-system:  Only use system Python installations; never use managed Python
-                installations
+          --no-managed-python
+              Disable use of uv-managed Python versions.
+              
+              Instead, uv will search for a suitable Python version on the system.
+              
+              [env: UV_NO_MANAGED_PYTHON=]
 
           --no-python-downloads
               Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
@@ -694,14 +689,14 @@ fn help_subsubcommand() {
 
 
     ----- stderr -----
-    "###);
+    "#);
 }
 
 #[test]
 fn help_flag_subcommand() {
     let context = TestContext::new_with_versions(&[]);
 
-    uv_snapshot!(context.filters(), context.command().arg("python").arg("--help"), @r###"
+    uv_snapshot!(context.filters(), context.command().arg("python").arg("--help"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -723,11 +718,10 @@ fn help_flag_subcommand() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations [env: UV_PYTHON_PREFERENCE=]
-              [possible values: only-managed, managed, system, only-system]
-          --no-python-downloads
-              Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
+          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+          --no-python-downloads  Disable automatic downloads of Python. [env:
+                                 "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet
@@ -761,14 +755,14 @@ fn help_flag_subcommand() {
     Use `uv help python` for more details.
 
     ----- stderr -----
-    "###);
+    "#);
 }
 
 #[test]
 fn help_flag_subsubcommand() {
     let context = TestContext::new_with_versions(&[]);
 
-    uv_snapshot!(context.filters(), context.command().arg("python").arg("install").arg("--help"), @r###"
+    uv_snapshot!(context.filters(), context.command().arg("python").arg("install").arg("--help"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -796,11 +790,10 @@ fn help_flag_subsubcommand() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations [env: UV_PYTHON_PREFERENCE=]
-              [possible values: only-managed, managed, system, only-system]
-          --no-python-downloads
-              Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
+          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+          --no-python-downloads  Disable automatic downloads of Python. [env:
+                                 "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet
@@ -832,7 +825,7 @@ fn help_flag_subsubcommand() {
               Display the uv version
 
     ----- stderr -----
-    "###);
+    "#);
 }
 
 #[test]
@@ -918,7 +911,7 @@ fn help_unknown_subsubcommand() {
 fn help_with_global_option() {
     let context = TestContext::new_with_versions(&[]);
 
-    uv_snapshot!(context.filters(), context.help().arg("--no-cache"), @r###"
+    uv_snapshot!(context.filters(), context.help().arg("--no-cache"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -953,11 +946,10 @@ fn help_with_global_option() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations [env: UV_PYTHON_PREFERENCE=]
-              [possible values: only-managed, managed, system, only-system]
-          --no-python-downloads
-              Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
+          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+          --no-python-downloads  Disable automatic downloads of Python. [env:
+                                 "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet
@@ -992,7 +984,7 @@ fn help_with_global_option() {
 
 
     ----- stderr -----
-    "###);
+    "#);
 }
 
 #[test]
@@ -1034,7 +1026,7 @@ fn help_with_no_pager() {
 
     // We can't really test whether the --no-pager option works with a snapshot test.
     // It's still nice to have a test for the option to confirm the option exists.
-    uv_snapshot!(context.filters(), context.help().arg("--no-pager"), @r###"
+    uv_snapshot!(context.filters(), context.help().arg("--no-pager"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1069,11 +1061,10 @@ fn help_with_no_pager() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --python-preference <PYTHON_PREFERENCE>
-              Whether to prefer uv-managed or system Python installations [env: UV_PYTHON_PREFERENCE=]
-              [possible values: only-managed, managed, system, only-system]
-          --no-python-downloads
-              Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
+          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+          --no-python-downloads  Disable automatic downloads of Python. [env:
+                                 "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet
@@ -1108,5 +1099,5 @@ fn help_with_no_pager() {
 
 
     ----- stderr -----
-    "###);
+    "#);
 }
