@@ -64,6 +64,38 @@ fn tool_list_paths() {
     "###);
 }
 
+#[cfg(windows)]
+#[test]
+fn tool_list_paths_windows() {
+    let context = TestContext::new("3.12")
+        .clear_filters()
+        .with_filtered_windows_temp_dir();
+    let tool_dir = context.temp_dir.child("tools");
+    let bin_dir = context.temp_dir.child("bin");
+
+    // Install `black`
+    context
+        .tool_install()
+        .arg("black==24.2.0")
+        .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
+        .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str())
+        .assert()
+        .success();
+
+    uv_snapshot!(context.filters_without_standard_filters(), context.tool_list().arg("--show-paths")
+    .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    black v24.2.0 ([TEMP_DIR]\tools\black)
+    - black.exe ([TEMP_DIR]\bin\black.exe)
+    - blackd.exe ([TEMP_DIR]\bin\blackd.exe)
+
+    ----- stderr -----
+    "###);
+}
+
 #[test]
 fn tool_list_empty() {
     let context = TestContext::new("3.12").with_filtered_exe_suffix();
